function output_seq = interp2b(input_seq, col_grid, row_grid)
    dims = size(input_seq);
    rows = dims(1);
    cols = dims(2);
    frames = prod(dims(3:end));

    [new_rows, new_cols] = size(col_grid);

    output_seq = NaN([new_rows new_cols dims(3:end)]);

    % Check for out of range values of col_grid and set to 1
    col_out_ind = find((col_grid<1)|(col_grid>cols));
    if length(col_out_ind)>0,
        col_grid(col_out_ind) = 1;
    end

    % Check for out of range values of row_grid and set to 1
    row_out_ind = find((row_grid<1)|(row_grid>rows));
    if length(row_out_ind)>0,
        row_grid(row_out_ind) = 1;
    end

    % Matrix element indexing
    ndx = floor(row_grid)+floor(col_grid-1)*rows;

    % Compute intepolation parameters, check for boundary value.
    if isempty(col_grid),
        d = col_grid;
    else
        d = find(col_grid==cols);
    end

    col_grid(:) = (col_grid - floor(col_grid));

    if length(d)>0,
        col_grid(d) = col_grid(d)+1;
        ndx(d) = ndx(d)-rows;
    end

    % Compute intepolation parameters, check for boundary value.
    if isempty(row_grid),
        d = row_grid;
    else
        d = find(row_grid==rows);
    end

    row_grid(:) = (row_grid - floor(row_grid));

    if length(d)>0,
        row_grid(d) = row_grid(d)+1;
        ndx(d) = ndx(d)-1;
    end

    % Now interpolate
    onemt = 1 - row_grid;

    for fr_i = 1:frames,
        frame = input_seq(:,:,fr_i);
        output_seq(:,:,fr_i) = ...
            ( frame(ndx).*(onemt) + frame(ndx+1).*row_grid ).*(1-col_grid) + ...
            ( frame(ndx+rows).*(onemt) + frame(ndx+(rows+1)).*row_grid ).*col_grid;
    end % frame-loop
end %function interp2b